@@ -24,6 +24,8 @@
 #include <QNetworkProxy>
 
 #include "mainwindow.h"
+#include "captchawindow.h"
+#include "authwindow.h"
 #include "authdbusadaptor.h"
 
 
@@ -40,6 +42,9 @@ const char* AuthDBusAdaptor::serviceName = "org.lomalan.AuthManager";
 const char* AuthDBusAdaptor::objectName = "/AuthManager";
 /** DBus signal with auth data. */
 const char* AuthDBusAdaptor::messageSignalName = "message";
+/** DBus signal with captcha data. */
+const char* AuthDBusAdaptor::captchamsgSignalName = "captchamsg";
+const char* AuthDBusAdaptor::loginmsgSignalName = "loginmsg";
 /** DBus signal to get command for shotdown service. */
 const char* AuthDBusAdaptor::shutdownSignalName = "shutdown";
 //@}
@@ -122,16 +127,21 @@ bool AuthDBusAdaptor::InitDBusService()
  *
  * @param signalName name of signal.
  * @param signalParams arguments(parameters) for signal.
+ * @param auth true - if use auth, false - if use captcha
  *
  * @return true on success, or false otherwise.
  */
-bool AuthDBusAdaptor::sendSignal(const QString &signalName, const QList<QVariant> &signalParams)
+bool AuthDBusAdaptor::sendSignal(const QString &signalName, const QList<QVariant> &signalParams, bool auth)
 {
     QString name;
     if (signalName.isEmpty() == true) {
-        name = messageSignalName;
+        if(auth){
+            name = messageSignalName;
+        } else {
+            name = captchamsgSignalName;
+        }
     } else {
-        name = signalName;
+            name = signalName;
     }
 
     QDBusMessage msg = QDBusMessage::createSignal(objectName, serviceName, name);
@@ -143,6 +153,23 @@ bool AuthDBusAdaptor::sendSignal(const QString &signalName, const QList<QVariant
 }
 
 
+bool AuthDBusAdaptor::sendLoginSignal(const QString &signalName, const QList<QVariant> &signalParams)
+{
+    QString name;
+    if (signalName.isEmpty() == true) {
+            name = loginmsgSignalName;
+    } else {
+            name = signalName;
+    }
+
+    QDBusMessage msg = QDBusMessage::createSignal(objectName, serviceName, name);
+    msg.setArguments(signalParams);
+
+    qDebug() << "Prepare for sending signal with name " << name;
+
+    return QDBusConnection::sessionBus().send(msg);
+}
+
 /**
  * @brief Getter for connection name.
  *
@@ -222,6 +249,28 @@ QString AuthDBusAdaptor::Auth(const QString &url, const QStringList &params)
     return "ok";
 }
 
+/**
+ * @brief Function to hadler dbus call.
+ * Function for DBus call, emit auth signal, simple test.
+ *
+ * @param strBase64 ar for test.
+ *
+ * @return now always return "ok" string.
+ */
+QString AuthDBusAdaptor::Captcha(const QString &strBase64, const QString clientID){
+
+    emit captcha(strBase64, clientID);
+
+    return "ok";
+}
+
+QString AuthDBusAdaptor::Login(const QString &clientID){
+
+    emit login(clientID);
+
+    return "ok";
+}
+
 
 void AuthDBusAdaptor::Shutdown()
 {
