@@ -53,9 +53,21 @@ class AuthDBusAdaptor: public QDBusAbstractAdaptor
         "      <arg direction=\"in\" type=\"s\" name=\"url\" />\n"
         "      <arg direction=\"out\" type=\"s\" name=\"authResult\" />\n"
         "    </method>\n"
+        "    <method name=\"Login\" >\n"
+        "      <arg direction=\"in\" type=\"s\" name=\"clientID\" />\n"
+        "      <arg direction=\"out\" type=\"s\" name=\"loginResult\" />\n"
+        "    </method>\n"
+        "    <method name=\"Captcha\" >\n"
+        "      <arg direction=\"in\" type=\"s\" name=\"strBase64\" />\n"
+        "      <arg direction=\"in\" type=\"s\" name=\"clientdID\" />\n"
+        "      <arg direction=\"out\" type=\"s\" name=\"captchaResult\" />\n"
+        "    </method>\n"
         "   <signal name=\"message\">\n"
         "            <arg direction=\"out\" type=\"as\" name=\"authResult\" />\n"
         "    </signal>\n"
+        "   <signal name=\"captchamsg\">\n"
+        "            <arg direction=\"out\" type=\"as\" name=\"captchaResult\" />\n"
+        "    </signal>\n"
         "  </interface>\n"
         "")
 
@@ -64,6 +76,8 @@ class AuthDBusAdaptor: public QDBusAbstractAdaptor
         static const char* serviceName;
         static const char* objectName;
         static const char* messageSignalName;
+        static const char* captchamsgSignalName;
+        static const char* loginmsgSignalName;
         static const char* shutdownSignalName;
 
         QDBusConnection connection;
@@ -73,7 +87,9 @@ class AuthDBusAdaptor: public QDBusAbstractAdaptor
         virtual ~AuthDBusAdaptor();
 
         bool InitDBusService();
-        static bool sendSignal(const QString &signalName, const QList<QVariant> &signalParams);
+        static bool sendSignal(const QString &signalName, const QList<QVariant> &signalParams, bool auth);
+        static bool sendLoginSignal(const QString &signalName, const QList<QVariant> &signalParams);
+
         const char* getConnectionName();
         const char* getShutdownSignalName();
 
@@ -83,7 +99,8 @@ class AuthDBusAdaptor: public QDBusAbstractAdaptor
 
         QString Auth(const QString &url, const QStringList &params);
         QString Auth(const QString &url);
-
+        QString Captcha(const QString &strBase64, const QString clientID);
+        QString Login(const QString &clientID);
         void Shutdown();
 
     Q_SIGNALS: //           SIGNALS
@@ -92,7 +109,8 @@ class AuthDBusAdaptor: public QDBusAbstractAdaptor
 
         void auth(const QString &url);
         void auth(const QString &url, const QStringList &params);
-
+        void captcha(const QString &strBase64, const QString clientID);
+        void login(const QString &clientID);
         void shutdown();
 };
 
