@@ -20,6 +20,8 @@ class AuthParams
         const QList<QString *> &getContextParams();
 
         QList<QVariant> prepareSignalParams(const QString & authResult, bool withRetParams);
+        QList<QVariant> prepareCaptchaSignalParams(const QString & captchaResult, bool withRetParams);
+        QList<QVariant> prepareLogInSignalParams(const QStringList & loginResult);
 
         void clear();
 
