@@ -323,7 +323,7 @@ void MainWindow::sendAuthResult(const QString &authResult, bool withReturnParams
     QList<QVariant> signalParams = authParams.prepareSignalParams(authResult, withReturnParams);
     const QString &clientID = authParams.getClientID();
 
-    if (AuthDBusAdaptor::sendSignal(clientID, signalParams) == false) {
+    if (AuthDBusAdaptor::sendSignal(clientID, signalParams, true) == false) {
         qDebug() << "\nMessage not send.";
     } else {
         qDebug() << "\nMessage send (" << signalParams << ").";
